"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefineTag = void 0;
const BodyTagSupport_js_1 = require("../util/BodyTagSupport.js");
const TagUtils_js_1 = require("../util/TagUtils.js");
/**
 * <bean:define>
 *
 * Define a scripting variable based on the value(s) of the specified bean
 * property.
 *
 * @see https://github.com/apache/struts1/blob/trunk/taglib/src/main/java/org/apache/struts/taglib/bean/DefineTag.java
 */
class DefineTag extends BodyTagSupport_js_1.BodyTagSupport {
    async render() {
        const { attr, context } = this;
        const { name, property, scope, id } = attr;
        let { value } = attr;
        const body = (await this.getBody())?.trim();
        // Enforce restriction on ways to declare the new value
        let n = 0;
        if (body)
            n++;
        if (name)
            n++;
        if (value)
            n++;
        if (n > 1) {
            throw new Error(`Define tag can contain only one of name attribute, value attribute, or body content for bean with id: ${id}`);
        }
        if (!value && name) {
            value = TagUtils_js_1.TagUtils.getInstance().lookup(context, name, property, scope);
        }
        if (!value && body) {
            value = body;
        }
        if (value == null) {
            throw new Error(`Define tag cannot set a null value for bean with id: ${id}`);
        }
        // Expose this value as a scripting variable
        context[id] = value;
    }
}
exports.DefineTag = DefineTag;
