"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HeaderTag = void 0;
const TagSupport_js_1 = require("../util/TagSupport.js");
/**
 * <bean:header>
 *
 * Define a scripting variable based on the value(s) of the specified header
 * received with this request.
 *
 * @see https://github.com/apache/struts1/blob/trunk/taglib/src/main/java/org/apache/struts/taglib/bean/HeaderTag.java
 *
 * @example
 * app.get("/", (req, res, next) => {
 *     const render = await nsp.load("/WEB-INF/views/index.jsp");
 *
 *     const ctx = {};
 *
 *     // store request object to context before rendering
 *     nsp.store(ctx, "req").set(req);
 *
 *     res.send(await render(ctx));
 * });
 */
class HeaderTag extends TagSupport_js_1.TagSupport {
    render() {
        const { multiple } = this.attr;
        if (multiple) {
            this.handleMultipleHeaders();
        }
        else {
            this.handleSingleHeader();
        }
    }
    handleMultipleHeaders() {
        const { id, name, value } = this.attr;
        let items = this.getRequest().getHeaders(name);
        if (!items?.length && value) {
            items = [value];
        }
        if (!items?.length) {
            throw new Error(`No header ${name} was included in this request`);
        }
        this.context[id] = items;
    }
    handleSingleHeader() {
        const { id, name, value } = this.attr;
        let item = this.getRequest().getHeader(name);
        if (!item && value) {
            item = value;
        }
        if (!item) {
            throw new Error(`No header ${name} was included in this request`);
        }
        this.context[id] = item;
    }
}
exports.HeaderTag = HeaderTag;
