"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParameterTag = void 0;
const TagSupport_js_1 = require("../util/TagSupport.js");
/**
 * <bean:parameter>
 *
 * Define a scripting variable based on the value(s) of the specified
 * parameter received with this request.
 *
 * @see https://github.com/apache/struts1/blob/trunk/taglib/src/main/java/org/apache/struts/taglib/bean/ParameterTag.java
 */
class ParameterTag extends TagSupport_js_1.TagSupport {
    render() {
        const { multiple } = this.attr;
        if (multiple) {
            this.handleMultiple();
        }
        else {
            this.handleSingle();
        }
    }
    handleMultiple() {
        const { id, name, value } = this.attr;
        let items = this.getRequest().getParameterValues(name);
        if (!items?.length && value) {
            items = [value];
        }
        if (!items?.length) {
            throw new Error(`No header ${name} was included in this request`);
        }
        this.context[id] = items;
    }
    handleSingle() {
        const { id, name, value } = this.attr;
        let item = this.getRequest().getParameter(name);
        if (!item && value) {
            item = value;
        }
        if (!item) {
            throw new Error(`No parameter ${name} was included in this request`);
        }
        this.context[id] = item;
    }
}
exports.ParameterTag = ParameterTag;
