"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResourceTag = void 0;
const toBoolean_js_1 = require("../internal/toBoolean.js");
const TagSupport_js_1 = require("../util/TagSupport.js");
/**
 * <bean:resource>
 *
 * Define a scripting variable based on the contents of the specified web
 * application resource.
 *
 * @see https://github.com/apache/struts1/blob/trunk/taglib/src/main/java/org/apache/struts/taglib/bean/ResourceTag.java
 *
 * @example
 * nsp.hook("bean:resource", (name) => {
 *     const path = `path/to/resources/${name}`;
 *     return fs.promises.readFile(path, "utf-8");
 * });
 */
class ResourceTag extends TagSupport_js_1.TagSupport {
    async render() {
        const { context } = this;
        const { name, id, input } = this.attr;
        if ((0, toBoolean_js_1.toBoolean)(input)) {
            throw new Error(`Not implemented: <bean:resource input="true">`);
        }
        const resource = await this.tag.app.process("bean:resource", name);
        if (resource == null) {
            throw new Error(`No resource ${name} available in this application`);
        }
        context[id] = resource;
    }
}
exports.ResourceTag = ResourceTag;
