"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SizeTag = void 0;
const TagSupport_js_1 = require("../util/TagSupport.js");
const TagUtils_js_1 = require("../util/TagUtils.js");
const isArrayLike = (v) => (!!v && "object" === typeof v && "number" === typeof v.length);
/**
 * <bean:size>
 *
 * Define a scripting variable that will contain the number of elements found
 * in a specified array, Collection, or Map.
 *
 * @see https://github.com/apache/struts1/blob/trunk/taglib/src/main/java/org/apache/struts/taglib/bean/SizeTag.java
 */
class SizeTag extends TagSupport_js_1.TagSupport {
    render() {
        const { id } = this.attr;
        const collection = this.getCollection();
        this.context[id] = collection?.length;
    }
    getCollection() {
        const { context } = this;
        const { name, property, scope } = this.attr;
        let collection = this.attr.collection;
        if (!collection) {
            collection = TagUtils_js_1.TagUtils.getInstance().lookup(context, name, property, scope);
        }
        if (isArrayLike(collection)) {
            return collection;
        }
        throw new Error(`No valid collection specified for size tag: ${name}`);
    }
}
exports.SizeTag = SizeTag;
