"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WriteTag = void 0;
const toBoolean_js_1 = require("../internal/toBoolean.js");
const TagSupport_js_1 = require("../util/TagSupport.js");
const TagUtils_js_1 = require("../util/TagUtils.js");
/**
 * <bean:write>
 *
 * Tag that retrieves the specified property of the specified bean, converts
 * it to a String representation (if necessary), and writes it to the current
 * output stream, optionally filtering characters that are sensitive in HTML.
 *
 * @see https://github.com/apache/struts1/blob/trunk/taglib/src/main/java/org/apache/struts/taglib/bean/WriteTag.java
 */
class WriteTag extends TagSupport_js_1.TagSupport {
    render() {
        const { context } = this;
        const { ignore, name, property, scope, filter } = this.attr;
        // Look up the requested bean (if necessary)
        if (ignore) {
            if (TagUtils_js_1.TagUtils.getInstance().lookup(context, name, scope) == null) {
                return; // Nothing to output
            }
        }
        // Look up the requested property value
        const value = TagUtils_js_1.TagUtils.getInstance().lookup(context, name, property, scope);
        if (value == null) {
            return; // Nothing to output
        }
        // Convert value to the String with some formatting
        const output = this.formatValue(value);
        // Print this property value to our output writer, suitably filtered
        if ((0, toBoolean_js_1.toBoolean)(filter) !== false) {
            return TagUtils_js_1.TagUtils.getInstance().filter(output);
        }
        else {
            return output;
        }
    }
    formatValue(valueToFormat) {
        let format;
        const value = valueToFormat;
        if ("string" === typeof value) {
            return value;
        }
        else {
            if ("number" === typeof value) {
                format = { format: JSON.stringify }; // TODO
            }
            else if (value instanceof Date) {
                format = { format: JSON.stringify }; // TODO
            }
        }
        if (format) {
            return format.format(value);
        }
        else {
            return String(value);
        }
    }
}
exports.WriteTag = WriteTag;
