"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseFieldTag = void 0;
const StringBuffer_js_1 = require("../util/StringBuffer.js");
const TagUtils_js_1 = require("../util/TagUtils.js");
const BaseHandlerTag_js_1 = require("./BaseHandlerTag.js");
const BaseInputTag_js_1 = require("./BaseInputTag.js");
class BaseFieldTag extends BaseInputTag_js_1.BaseInputTag {
    render() {
        let results = this.renderInputElement();
        return results.toString();
    }
    /**
     * Renders a fully formed &lt;input&gt; element.
     */
    renderInputElement() {
        const { attr } = this;
        const results = new StringBuffer_js_1.StringBuffer("<input");
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "type", this.type);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "name", attr.property);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "accesskey", attr.accesskey);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "accept", attr.accept);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "maxlength", attr.maxlength);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "size", attr.cols);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "tabindex", attr.tabindex);
        this.prepareValue(results);
        results.append(this.prepareEventHandlers());
        results.append(this.prepareStyles());
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "autocomplete", attr.autocomplete);
        this.prepareOtherAttributes(results);
        results.append(this.getElementClose());
        return results;
    }
    /**
     * Render the value element
     */
    prepareValue(results) {
        const { attr } = this;
        results.append(" value=\"");
        if (attr.value != null) {
            results.append(this.formatValue(attr.value));
        }
        else if (attr.redisplay || !("password" == this.type)) {
            const value = TagUtils_js_1.TagUtils.getInstance().lookup(this.context, this.name, attr.property, null);
            results.append(this.formatValue(value));
        }
        results.append('"');
    }
    /**
     * Return the given value as a formatted <code>String</code>.  This
     * implementation escapes potentially harmful HTML characters.
     */
    formatValue(value) {
        if (value == null) {
            return "";
        }
        return TagUtils_js_1.TagUtils.getInstance().filter(value.toString());
    }
}
exports.BaseFieldTag = BaseFieldTag;
