"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.prepareAttribute = exports.BaseHandlerTag = void 0;
const telesy_1 = require("telesy");
const BeanUtils_js_1 = require("../util/BeanUtils.js");
const BodyTagSupport_js_1 = require("../util/BodyTagSupport.js");
const StringBuffer_js_1 = require("../util/StringBuffer.js");
const TagUtils_js_1 = require("../util/TagUtils.js");
class BaseHandlerTag extends BodyTagSupport_js_1.BodyTagSupport {
    constructor() {
        super(...arguments);
        /**
         * Indicates whether 'disabled' is a valid attribute.
         */
        this.doDisabled = true;
        /**
         * Indicates whether 'readonly' is a valid attribute.
         */
        this.doReadonly = false;
    }
    /**
     * Determine if there are errors for the component.
     * TODO
     */
    doErrorsExist() {
        return false;
    }
    /**
     * Prepares the style attributes for inclusion in the component's HTML
     * tag.
     */
    prepareStyles() {
        const errorsExist = this.doErrorsExist();
        const { attr } = this;
        const styles = new StringBuffer_js_1.StringBuffer();
        if (errorsExist && attr.errorStyleId != null) {
            (0, exports.prepareAttribute)(styles, "id", attr.errorStyleId);
        }
        else {
            (0, exports.prepareAttribute)(styles, "id", attr.styleId);
        }
        if (errorsExist && attr.errorStyle != null) {
            (0, exports.prepareAttribute)(styles, "style", attr.errorStyle);
        }
        else {
            (0, exports.prepareAttribute)(styles, "style", attr.style);
        }
        if (errorsExist && attr.errorStyleClass != null) {
            (0, exports.prepareAttribute)(styles, "class", attr.errorStyleClass);
        }
        else {
            (0, exports.prepareAttribute)(styles, "class", attr.styleClass);
        }
        // TODO: message(getTitle(), getTitleKey())
        (0, exports.prepareAttribute)(styles, "title", attr.title);
        // TODO: message(getAlt(), getAltKey())
        (0, exports.prepareAttribute)(styles, "alt", attr.alt);
        this.prepareInternationalization(styles);
        return styles.toString();
    }
    /**
     * Prepares the event handlers for inclusion in the component's HTML tag.
     */
    prepareEventHandlers() {
        const handlers = new StringBuffer_js_1.StringBuffer();
        this.prepareMouseEvents(handlers);
        this.prepareKeyEvents(handlers);
        this.prepareTextEvents(handlers);
        this.prepareFocusEvents(handlers);
        return handlers.toString();
    }
    /**
     * Prepares the mouse event handlers, appending them to the given
     * StringBuffer.
     */
    prepareMouseEvents(handlers) {
        const { attr } = this;
        (0, exports.prepareAttribute)(handlers, "onclick", attr.onclick);
        (0, exports.prepareAttribute)(handlers, "ondblclick", attr.ondblclick);
        (0, exports.prepareAttribute)(handlers, "onmouseover", attr.onmouseover);
        (0, exports.prepareAttribute)(handlers, "onmouseout", attr.onmouseout);
        (0, exports.prepareAttribute)(handlers, "onmousemove", attr.onmousemove);
        (0, exports.prepareAttribute)(handlers, "onmousedown", attr.onmousedown);
        (0, exports.prepareAttribute)(handlers, "onmouseup", attr.onmouseup);
    }
    /**
     * Prepares the keyboard event handlers, appending them to the given
     * StringBuffer.
     */
    prepareKeyEvents(handlers) {
        const { attr } = this;
        (0, exports.prepareAttribute)(handlers, "onkeydown", attr.onkeydown);
        (0, exports.prepareAttribute)(handlers, "onkeyup", attr.onkeyup);
        (0, exports.prepareAttribute)(handlers, "onkeypress", attr.onkeypress);
    }
    /**
     * Prepares the text event handlers, appending them to the given
     * StringBuffer.
     */
    prepareTextEvents(handlers) {
        const { attr } = this;
        (0, exports.prepareAttribute)(handlers, "onselect", attr.onselect);
        (0, exports.prepareAttribute)(handlers, "onchange", attr.onchange);
    }
    /**
     * Prepares the focus event handlers, appending them to the given
     * StringBuffer.
     */
    prepareFocusEvents(handlers) {
        const { attr, doDisabled, doReadonly } = this;
        (0, exports.prepareAttribute)(handlers, "onblur", attr.onblur);
        (0, exports.prepareAttribute)(handlers, "onfocus", attr.onfocus);
        if (doDisabled) {
            if (attr.disabled) {
                handlers.append(` disabled="disabled"`);
            }
        }
        if (doReadonly) {
            if (attr.readonly) {
                handlers.append(` readonly="readonlyl"`);
            }
        }
    }
    /**
     * Prepares the internationalization attribtes, appending them to the given
     * StringBuffer.
     */
    prepareInternationalization(handlers) {
        const { attr } = this;
        (0, exports.prepareAttribute)(handlers, "bundle", attr.bundle);
        (0, exports.prepareAttribute)(handlers, "dir", attr.dir);
    }
    /**
     * 'Hook' to enable tags to be extended and additional attributes added.
     */
    prepareOtherAttributes(_) {
        //
    }
    /**
     * Prepares an attribute if the value is not null, appending it to the
     * given StringBuffer.
     */
    prepareAttribute(handlers, name, value) {
        return (0, exports.prepareAttribute)(handlers, name, value);
    }
    /**
     * Returns the closing brace for an input element
     */
    getElementClose() {
        return ">";
    }
    /**
     * Searches all scopes for the bean and calls BeanUtils.getProperty() with
     * the given arguments and converts any exceptions into JspException.
     */
    lookupProperty(beanName, property) {
        const bean = TagUtils_js_1.TagUtils.getInstance().lookup(this.context, beanName, null);
        if (bean == null) {
            throw new Error(`Cannot find bean under name ${beanName}`);
        }
        try {
            return BeanUtils_js_1.BeanUtils.getProperty(bean, property);
        }
        catch (e) {
            throw new Error(`Cannot access property ${property} for bean under name ${beanName}`);
        }
    }
}
exports.BaseHandlerTag = BaseHandlerTag;
const prepareAttribute = (handlers, name, value) => {
    if (value === true) {
        handlers.append((0, telesy_1.$$) ` ${name}`);
    }
    else if (value != null) {
        handlers.append((0, telesy_1.$$) ` ${name}="${String(value)}"`);
    }
};
exports.prepareAttribute = prepareAttribute;
