"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MultiboxTag = void 0;
const StringBuffer_js_1 = require("../util/StringBuffer.js");
const BaseHandlerTag_js_1 = require("./BaseHandlerTag.js");
/**
 * <html:multibox>
 *
 * @see https://github.com/apache/struts1/blob/trunk/taglib/src/main/java/org/apache/struts/taglib/html/MultiboxTag.java
 */
class MultiboxTag extends BaseHandlerTag_js_1.BaseHandlerTag {
    async render() {
        const { attr } = this;
        const body = await this.getBody();
        if (body)
            this.constant = body.trim();
        const results = new StringBuffer_js_1.StringBuffer(`<input type="checkbox"`);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "name", attr.property);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "accesskey", attr.accesskey);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "tabindex", attr.tabindex);
        const value = this.prepareValue(results);
        this.prepareChecked(results, value);
        results.append(this.prepareEventHandlers());
        results.append(this.prepareStyles());
        this.prepareOtherAttributes(results);
        results.append(this.getElementClose());
        return results.toString();
    }
    /**
     * Render the value element
     */
    prepareValue(results) {
        const value = this.attr.value ?? this.constant;
        if (value == null) {
            throw new Error(`You must specify the value attribute or nested tag content`);
        }
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "value", value);
        return value;
    }
    /**
     * Render the checked element
     */
    prepareChecked(results, value) {
        const checked = this.context[this.attr.property];
        if (checkArray(checked, value)) {
            (0, BaseHandlerTag_js_1.prepareAttribute)(results, "checked", "checked");
        }
    }
}
exports.MultiboxTag = MultiboxTag;
const checkArray = (checked, value) => {
    if (Array.isArray(checked)) {
        return checked.find(v => checkValue(v, value));
    }
    else {
        return checkValue(checked, value);
    }
};
const checkValue = (checked, value) => {
    return ("object" !== typeof checked && checked == value);
};
