"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SelectTag = void 0;
const toBoolean_js_1 = require("../internal/toBoolean.js");
const BeanUtils_js_1 = require("../util/BeanUtils.js");
const StringBuffer_js_1 = require("../util/StringBuffer.js");
const TagUtils_js_1 = require("../util/TagUtils.js");
const BaseHandlerTag_js_1 = require("./BaseHandlerTag.js");
const Constants_js_1 = require("./Constants.js");
/**
 * <html:select>
 *
 * @see https://github.com/apache/struts1/blob/trunk/taglib/src/main/java/org/apache/struts/taglib/html/SelectTag.java
 */
class SelectTag extends BaseHandlerTag_js_1.BaseHandlerTag {
    constructor() {
        super(...arguments);
        /**
         * The actual values we will match against, calculated in doStartTag().
         */
        this.match = null;
        /**
         * The saved body content of this tag.
         */
        this.saveBody = null;
    }
    async render() {
        const results = new StringBuffer_js_1.StringBuffer();
        results.append(this.renderSelectStartElement());
        // Store this tag itself as a page attribute
        this.context[Constants_js_1.Constants.SELECT_KEY] = this;
        this.calculateMatchValues();
        if (this.getBody() != null) {
            let value = await this.getBody();
            if (value == null) {
                value = "";
            }
            this.saveBody = value.trim();
        }
        // Remove the page scope attributes we created
        delete this.context[Constants_js_1.Constants.SELECT_KEY];
        // Render a tag representing the end of our current form
        if (this.saveBody != null) {
            results.append(this.saveBody);
            this.saveBody = null;
        }
        results.append("</select>");
        return results.toString();
    }
    /**
     * Does the specified value match one of those we are looking for?
     */
    isMatched(value) {
        if ((this.match == null) || (value == null)) {
            return false;
        }
        for (let i = 0; i < this.match.length; i++) {
            if (value == this.match[i]) {
                return true;
            }
        }
        return false;
    }
    /**
     * Create an appropriate select start element based on our parameters.
     */
    renderSelectStartElement() {
        const { attr } = this;
        const results = new StringBuffer_js_1.StringBuffer("<select");
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "name", attr.property);
        // TODO
        // prepareAttribute(results, "accesskey", attr.accesskey);
        if ((0, toBoolean_js_1.toBoolean)(attr.multiple)) {
            results.append(" multiple=\"multiple\"");
        }
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "size", attr.size);
        (0, BaseHandlerTag_js_1.prepareAttribute)(results, "tabindex", attr.tabindex);
        results.append(this.prepareEventHandlers());
        results.append(this.prepareStyles());
        this.prepareOtherAttributes(results);
        results.append(">");
        return results.toString();
    }
    /**
     * Calculate the match values we will actually be using.
     */
    calculateMatchValues() {
        const { attr } = this;
        if (attr.value != null) {
            this.match = [];
            this.match[0] = attr.value;
        }
        else {
            const bean = TagUtils_js_1.TagUtils.getInstance().lookup(this.context, attr.name, null);
            if (bean == null) {
                throw new Error(`Cannot find bean under name ${attr.name}`);
            }
            try {
                this.match = BeanUtils_js_1.BeanUtils.getArrayProperty(bean, attr.property);
                if (this.match == null) {
                    this.match = [];
                }
            }
            catch (e) {
                throw new Error(`Cannot access property ${attr.property} for bean under name ${attr.name}`);
            }
        }
    }
}
exports.SelectTag = SelectTag;
