import { Cookie } from "./Cookie.js";
/**
 * A bridge implementation from NSP to Tomcat Catalina
 *
 * @see https://github.com/apache/tomcat/blob/main/java/org/apache/catalina/connector/Request.java
 */
export class Request {
    constructor(app, context) {
        this.app = app;
        this.context = context;
        //
    }
    getCookies() {
        return this.cookies ??= bakeCookies(this.getRequest());
    }
    getHeader(name) {
        const { headers } = this.getRequest();
        const item = headers[name] ?? headers[name?.toLowerCase()];
        if (item == null)
            return;
        if (Array.isArray(item))
            return item[0];
        return item;
    }
    getHeaders(name) {
        const { headers } = this.getRequest();
        const item = headers[name] ?? headers[name?.toLowerCase()];
        if (item == null)
            return;
        if ("object" === typeof item)
            return item; // Partial<ArrayLike>
        return [item];
    }
    getParameter(name) {
        const { query } = this.getRequest();
        const item = query?.[name];
        if (item == null)
            return;
        if (Array.isArray(item))
            return item[0];
        return item;
    }
    getParameterValues(name) {
        const { query } = this.getRequest();
        const item = query?.[name];
        if (item == null)
            return;
        if ("object" === typeof item)
            return item; // Partial<ArrayLike>
        return [item];
    }
    getRequest() {
        const request = this.app.store(this.context, "req").get();
        if (!request) {
            throw new Error(`request not stored in context`);
        }
        return request;
    }
}
const bakeCookies = (req) => {
    const cookies = req.cookies || {};
    const items = [];
    Object.keys(cookies).map(key => {
        const value = cookies[key];
        if (Array.isArray(value)) {
            value.forEach(value => items.push(new Cookie(key, value)));
        }
        else {
            items.push(new Cookie(key, value));
        }
    });
    return items;
};
